% Copyright (C) Paweł Płazieński 2009
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by the
% Free Software Foundation; either version 2, or (at your option) any
% later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

ugraph_draw(G,EdgeColor,Format) :-
	ugraph_draw_header,
	ugraph_draw_body(G,EdgeColor,Format),
	ugraph_draw_footer.

ugraph_draw_list(GList,EdgeColorList,Format) :-
	ugraph_draw_header,
	ugraph_draw_list_helper(GList,EdgeColorList,Format),
	ugraph_draw_footer.

ugraph_draw_list_helper([G|RG],[EdgeColor|REdgeColor],Format) :-
	ugraph_draw_body(G,EdgeColor,Format),
	ugraph_draw_list_helper(RG,REdgeColor,Format).

ugraph_draw_list_helper([],[],_).

ugraph_draw_header :-
	tell(pipe('dot -Tpng | display -title ARD_history &')),
	write('digraph G {'),nl,
	write(' rankdir=LR'),nl,
	write(' node [shape=box, fontsize=9, height=0.1, width=0.05 ]'),nl,
	write(' edge [arrowsize=0.5, len=0.1]'),nl.

ugraph_draw_footer :-
	write('}'),nl,
	told.

ugraph_draw_body(G,_,Format):-
	vertices(G,Vs),
	member(V,Vs),
	write('"'),formated_write(V,Format),write('"'),
	nl,
	fail.

ugraph_draw_body(G,EdgeColor,Format):-
	edges(G,Es),
	member(E,Es),
	E = F-T,
	write('"'),formated_write(F,Format),write('"'),
	write('->'),
	write('"'),formated_write(T,Format),write('"'),
	write('[color='), write(EdgeColor), write(']'),
	nl,
	fail.

ugraph_draw_body(_,_,_).

formated_write(Unprocessed,Format) :-
	functor(FormatPredicate,Format,2),
	FormatPredicate =.. [Format,Unprocessed,Processed],
	FormatPredicate,
	write(Processed).

